nwbwidgets.analysis package
===========================

Submodules
----------

nwbwidgets.analysis.spikes module
---------------------------------

.. automodule:: nwbwidgets.analysis.spikes
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nwbwidgets.analysis
   :members:
   :undoc-members:
   :show-inheritance:
